@@ -79,40 +79,6 @@ For the Format.Writer class:
 
 """
 
-from ..core.imopen import imopen
-
-try:
-    import PIL
-    from .pillow import PillowPlugin
-
-    imopen.register_plugin("pillow", PillowPlugin)
-except ImportError:
-    pass  # Pillow not installed
-
-
-# First import plugins that we want to take precedence over freeimage
-from . import tifffile
-from . import fits  # depends on astropy
-from . import pillow_legacy
-from . import grab
-
-from . import freeimage
-from . import freeimagemulti
-
-from . import ffmpeg
-
-from . import bsdf
-from . import dicom
-from . import npz
-from . import swf
-
-from . import feisem  # special kind of tiff, uses _tiffile
-from . import simpleitk  # depends on itk or SimpleITK
-from . import gdal  # depends on gdal
-
-from . import lytro
-from . import spe
-
 from . import example
 
 # Sort
