@@ -202,7 +202,6 @@ from typing import Any, Callable, Dict, Mapping, Optional, Sequence, Union
 
 import numpy as np
 
-from .. import formats
 from ..core import Format
 
 
@@ -754,7 +753,3 @@ def roi_array_to_dict(a):
         }
         dict_list.append(roi_dict)
     return dict_list
-
-
-fmt = SpeFormat("spe", "SPE file format", ".spe", "iIvV")
-formats.add_format(fmt, overwrite=True)
