@@ -93,9 +93,13 @@ def test_select():
     assert not F.can_read(core.Request(fname1, "rv"))
 
     # ffmpeg is default
-    assert imageio.formats[".mp4"] is F
-    assert imageio.formats.search_write_format(core.Request(fname1, "wI")) is F
-    assert imageio.formats.search_read_format(core.Request(fname1, "rI")) is F
+    assert type(imageio.formats[".mp4"]) is type(F)
+    assert type(
+        imageio.formats.search_write_format(core.Request(fname1, "wI"))
+    ) is type(F)
+    assert type(imageio.formats.search_read_format(core.Request(fname1, "rI"))) is type(
+        F
+    )
 
 
 def test_integer_reader_length():
@@ -111,7 +115,7 @@ def test_integer_reader_length():
 def test_read_and_write():
 
     R = imageio.read(get_remote_file("images/cockatoo.mp4"), "ffmpeg")
-    assert R.format is imageio.formats["ffmpeg"]
+    assert isinstance(R.format, type(imageio.formats["ffmpeg"]))
 
     fname1 = get_remote_file("images/cockatoo.mp4", test_dir)
     fname2 = fname1[:-4] + ".out.mp4"
@@ -180,7 +184,7 @@ def test_read_and_write():
 def test_write_not_contiguous():
 
     R = imageio.read(get_remote_file("images/cockatoo.mp4"), "ffmpeg")
-    assert R.format is imageio.formats["ffmpeg"]
+    assert isinstance(R.format, type(imageio.formats["ffmpeg"]))
 
     fname1 = get_remote_file("images/cockatoo.mp4", test_dir)
     fname2 = fname1[:-4] + ".out.mp4"
@@ -469,10 +473,24 @@ def test_framecatcher():
 
 
 def test_webcam():
-    try:
-        imageio.read("<video0>")
-    except Exception:
-        skip("no web cam")
+    good_paths = ["<video0>", "<video42>"]
+    for path in good_paths:
+        # regression test for https://github.com/imageio/imageio/issues/676
+        tmp_request = imageio.core.Request(path, "rI")
+        assert imageio.formats["ffmpeg"].can_read(tmp_request)
+        tmp_request.finish()
+
+        try:
+            imageio.read(path, format="ffmpeg")
+        except IndexError:
+            # IndexError should be raised when
+            # path string is good but camera doesnt exist
+            continue
+
+    bad_paths = ["<videof1>", "<video0x>", "<video>"]
+    for path in bad_paths:
+        with raises(ValueError):
+            imageio.read(path)
 
 
 def test_webcam_get_next_data():
